@@ -6,7 +6,7 @@
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
  * Copyright (c) 1996-2000 Grace Development Team
  * 
- * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
+ * Maintained by Evgeny Stambulchik
  * 
  * 
  *                           All Rights Reserved
@@ -629,12 +629,17 @@ int ep_aac_proc(void *data)
     EditPoints *ep = (EditPoints *) data;
     int stype;
     char *comment;
+    int cur_row, cur_col;
     
     stype = GetOptionChoice(ep->stype);
     comment = GetTextString(ep->comment);
     
     set_dataset_type(ep->gno, ep->setno, stype);
     setcomment(ep->gno, ep->setno, comment);
+    /* commit the last entered cell changes */
+    XbaeMatrixGetCurrentCell(ep->mw, &cur_row, &cur_col);
+    XbaeMatrixEditCell(ep->mw, cur_row, cur_col);
+    
     update_set_lists(ep->gno);
     xdrawgraph();
     
