@@ -6,7 +6,7 @@
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
  * Copyright (c) 1996-2002 Grace Development Team
  * 
- * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
+ * Maintained by Evgeny Stambulchik
  * 
  * 
  *                           All Rights Reserved
@@ -153,22 +153,24 @@ int realloc_ss_data(ss_data *ssd, int nrows)
 
 void free_ss_data(ss_data *ssd)
 {
-    int i, j;
-    char  **sp;
-    
-    for (i = 0; i < ssd->ncols; i++) {
-        if (ssd->formats[i] == FFORMAT_STRING) {
-            sp = (char **) ssd->data[i];
-            for (j = 0; j < ssd->nrows; j++) {
-                XCFREE(sp[j]);
+    if (ssd) {
+        int i, j;
+        char  **sp;
+
+        for (i = 0; i < ssd->ncols; i++) {
+            if (ssd->formats && ssd->formats[i] == FFORMAT_STRING) {
+                sp = (char **) ssd->data[i];
+                for (j = 0; j < ssd->nrows; j++) {
+                    XCFREE(sp[j]);
+                }
             }
+            XCFREE(ssd->data[i]);
         }
-        XCFREE(ssd->data[i]);
+        XCFREE(ssd->data);
+        XCFREE(ssd->formats);
+        ssd->nrows = 0;
+        ssd->ncols = 0;
     }
-    XCFREE(ssd->data);
-    XCFREE(ssd->formats);
-    ssd->nrows = 0;
-    ssd->ncols = 0;
 }
 
 int init_ss_data(ss_data *ssd, int ncols, int *formats)
@@ -179,7 +181,8 @@ int init_ss_data(ss_data *ssd, int ncols, int *formats)
     for (i = 0; i < ncols; i++) {
         ssd->data[i] = NULL;
     }
-    ssd->formats = formats;
+    ssd->formats = xmalloc(ncols*SIZEOF_INT);
+    memcpy(ssd->formats, formats, ncols*SIZEOF_INT);
     ssd->ncols = ncols;
     ssd->nrows = 0;
 
@@ -369,8 +372,8 @@ int store_data(ss_data *ssd, int load_type, char *label)
     
     switch (load_type) {
     case LOAD_SINGLE:
-        if (nncols > MAX_SET_COLS || nscols > 1) {
-            errmsg("Internal error");
+        if (nscols > 1) {
+            errmsg("Can not use more than one column of strings per set");
             free_ss_data(ssd);
             return RETURN_FAILURE;
         }
@@ -409,6 +412,7 @@ int store_data(ss_data *ssd, int load_type, char *label)
         }
         
         XCFREE(ssd->data);
+        XCFREE(ssd->formats);
         break;
     case LOAD_NXY:
         if (nscols != 0) {
@@ -438,6 +442,7 @@ int store_data(ss_data *ssd, int load_type, char *label)
         }
     
         XCFREE(ssd->data);
+        XCFREE(ssd->formats);
         break;
     case LOAD_BLOCK:
         set_blockdata(ssd);
@@ -531,7 +536,7 @@ int create_set_fromblock(int gno, int setno,
 {
     int i, ncols, blockncols, blocklen, column;
     double *cdata;
-    char buf[256];
+    char buf[256], *s;
 
     blockncols = get_blockncols();
     if (blockncols <= 0) {
@@ -611,7 +616,9 @@ int create_set_fromblock(int gno, int setno,
         }
     }
 
-    sprintf(buf, "Cols %s", cols_to_field_string(nc, coli, scol));
+    s = cols_to_field_string(nc, coli, scol);
+    sprintf(buf, "Cols %s", s);
+    xfree(s);
     setcomment(gno, setno, buf);
 
     autoscale_graph(gno, autoscale);
